<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Andrew Pleshakov <beotiger@mail.ru>
 * @author Змей Этерийский evil_snake@eternion.ru
 * @author Hikaru Nakajima <jisatsu@mail.ru>
 * @author Alexei Tereschenko <alexeitlex@yahoo.com>
 * @author Irina Ponomareva irinaponomareva@webperfectionist.com
 * @author Alexander Sorkin <kibizoid@gmail.com>
 * @author Kirill Krasnov <krasnovforum@gmail.com>
 * @author Vlad Tsybenko <vlad.development@gmail.com>
 * @author Aleksey Osadchiy <rfc@nm.ru>
 * @author Aleksandr Selivanov <alexgearbox@gmail.com>
 * @author Ladyko Andrey <fylh@succexy.spb.ru>
 * @author Eugene <windy.wanderer@gmail.com>
 * @author Johnny Utah <pcpa@cyberpunk.su>
 * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
 */
$lang['menu']                  = 'Управление плагинами';
$lang['download']              = 'Скачать и установить новый плагин';
$lang['manage']                = 'Установленные плагины';
$lang['btn_info']              = 'данные';
$lang['btn_update']            = 'обновить';
$lang['btn_delete']            = 'удалить';
$lang['btn_settings']          = 'настройки';
$lang['btn_download']          = 'Скачать';
$lang['btn_enable']            = 'Сохранить';
$lang['url']                   = 'Адрес';
$lang['installed']             = 'Установлен:';
$lang['lastupdate']            = 'Последнее обновление:';
$lang['source']                = 'Источник:';
$lang['unknown']               = 'неизвестно';
$lang['updating']              = 'Обновление...';
$lang['updated']               = 'Плагин %s успешно обновлён';
$lang['updates']               = 'Следующие плагины были успешно обновлены';
$lang['update_none']           = 'Обновления не найдены.';
$lang['deleting']              = 'Удаление...';
$lang['deleted']               = 'Плагин %s удалён.';
$lang['downloading']           = 'Скачивание...';
$lang['downloaded']            = 'Плагин %s успешно установлен';
$lang['downloads']             = 'Следующие плагины были успешно установлены:';
$lang['download_none']         = 'Плагины не найдены или возникла неизвестная проблема в процессе скачивания и установки.';
$lang['plugin']                = 'Плагин:';
$lang['components']            = 'Компоненты';
$lang['noinfo']                = 'Этот плагин не сообщил никаких данных, он может быть нерабочим.';
$lang['name']                  = 'Название:';
$lang['date']                  = 'Дата:';
$lang['type']                  = 'Тип:';
$lang['desc']                  = 'Описание:';
$lang['author']                = 'Автор:';
$lang['www']                   = 'Страница:';
$lang['error']                 = 'Произошла неизвестная ошибка.';
$lang['error_download']        = 'Не могу скачать файл плагина: %s';
$lang['error_badurl']          = 'Возможно неправильный адрес — не могу определить имя файла из адреса';
$lang['error_dircreate']       = 'Не могу создать временную директорию для скачивания';
$lang['error_decompress']      = 'Менеджеру плагинов не удалось распаковать скачанный файл. Это может быть результатом ошибки при скачивании, в этом случае вы можете попробовать снова, или же плагин упакован неизвестным архиватором, тогда вам необходимо скачать и установить плагин вручную.';
$lang['error_copy']            = 'Произошла ошибка копирования при попытке установки файлов для плагина <em>%s</em>: переполнение диска или неправильные права доступа. Это могло привести к частичной установке плагина и неустойчивости работы вашей вики.';
$lang['error_delete']          = 'Произошла ошибка при попытке удалить плагин <em>%s</em>.  Наиболее вероятно, что нет необходимых прав доступа к файлам или директориям';
$lang['enabled']               = 'Плагин %s включен.';
$lang['notenabled']            = 'Не удалось включить плагин %s. Проверьте системные права доступа к файлам.';
$lang['disabled']              = 'Плагин %s отключен.';
$lang['notdisabled']           = 'Не удалось отключить плагин %s. Проверьте системные права доступа к файлам.';
$lang['packageinstalled']      = 'Пакет (%d плагин(а): %s) успешно установлен.';
